@@ -26,6 +26,10 @@ has description => '';
 has error       => undef;                                                # {message => "", code => ""}
 has height      => sub { $_[0]->type =~ /^photo|video$/ ? 0 : undef };
 
+has placeholder_url => sub {
+  return sprintf 'http://placehold.it/200x200?text=%s', shift->provider_name;
+};
+
 has provider_name => sub {
   return undef unless my $name = shift->url->host;
   return $name =~ /([^\.]+)\.(\w+)$/ ? ucfirst $1 : $name;
@@ -44,9 +48,11 @@ has version          => '1.0';
 has width            => sub { $_[0]->type =~ /^photo|video$/ ? 0 : undef };
 
 sub html {
-  my $self = shift;
+  my $self     = shift;
   my $template = Mojo::Loader::data_section(@{$self->template}) or return '';
-  Mojo::Template->new({auto_escape => 1, prepend => 'my $l=shift'})->render($template, $self);
+  my $output   = Mojo::Template->new({auto_escape => 1, prepend => 'my $l=shift'})->render($template, $self);
+  die $output if ref $output;
+  return $output;
 }
 
 sub learn {
@@ -122,6 +128,8 @@ sub _learn_from_json {
 
   warn "[LinkEmbedder] " . $tx->res->text . "\n" if DEBUG;
   $self->{$_} ||= $json->{$_} for keys %$json;
+  $self->{error} = {message => $self->{error}} if defined $self->{error} and !ref $self->{error};
+  $self->{error}{code} = $self->{status} if $self->{status} and $self->{status} =~ /^\d+$/;
 }
 
 sub _learn_from_url {
@@ -132,11 +140,6 @@ sub _learn_from_url {
   $self;
 }
 
-sub _wash {
-  $_[1] or return $_[0];
-  $_[1]->find($_)->map('remove') for qw(embed script);
-}
-
 1;
 
 =encoding utf8
@@ -294,24 +297,47 @@ L<LinkEmbedder>
 
 __DATA__
 @@ iframe.html.ep
-<iframe width="600" height="400" style="border:0;width:100%" frameborder="0" allowfullscreen src="<%= $l->{iframe_src} %>"></iframe>
+<iframe class="le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>" width="<%= $l->width || 600 %>" height="<%= $l->height || 400 %>" style="border:0;width:100%" frameborder="0" allowfullscreen src="<%= $l->{iframe_src} %>"></iframe>
 @@ link.html.ep
-<a href="<%= $l->url %>"><%= Mojo::Util::url_unescape($l->url) %></a>
+<a class="le-<%= $l->type %>" href="<%= $l->url %>" title="<%= $l->title || '' %>"><%= Mojo::Util::url_unescape($l->url) %></a>
 @@ paste.html.ep
-<pre><%= $l->{paste} || '' %></pre>
+<div class="le-paste le-provider-<%= lc $l->provider_name %> le-<%= $l->type %>">
+  <div class="le-meta">
+    <span class="le-provider-link"><a href="<%= $l->provider_url %>"><%= $l->provider_name %></a></span>
+    <span class="le-goto-link"><a href="<%= $l->url %>" title="<%= $l->title %>"><%= $l->{paste_name} || $l->author_name || 'View' %></a></span>
+  </div>
+  <pre><%= $l->{paste} || '' %></pre>
+</div>
 @@ photo.html.ep
-<img src="<%= $l->url %>" alt="<%= $l->title %>">
+<div class="le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>">
+  <img src="<%= $l->url %>" alt="<%= $l->title %>">
+</div>
 @@ rich.html.ep
 % if ($l->title) {
-<div class="card le-card le-<%= $l->type %>">
+  % if (my $thumbnail_url = $l->thumbnail_url || $l->placeholder_url) {
+<div class="le-card le-image-card le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>">
+    <a href="<%= $l->url %>" class="le-thumbnail<%= $l->thumbnail_url ? '' : '-placeholder' %>">
+      <img src="<%= $thumbnail_url %>" alt="<%= $l->author_name || 'Placeholder' %>">
+    </a>
+  % } else {
+<div class="le-card le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>">
+  % }
   <h3><%= $l->title %></h3>
-  <p><%= $l->description %></p>
+    % if ($l->description) {
+  <p class="le-description"><%= $l->description %></p>
+    % }
+  <div class="le-meta">
+    % if ($l->author_name) {
+    <span class="le-author-link"><a href="<%= $l->author_url || $l->url %>"><%= $l->author_name %></a></span>
+    % }
+    <span class="le-goto-link"><a href="<%= $l->url %>"><span><%= $l->url %></span></a></span>
+  </div>
 </div>
 % } else {
-<a href="<%= $l->url %>"><%= Mojo::Util::url_unescape($l->url) %></a>
+<a class="le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>" href="<%= $l->url %>"><%= Mojo::Util::url_unescape($l->url) %></a>
 % }
 @@ video.html.ep
-<video height="640" width="480" preload="metadata" controls>
+<video class="le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>" height="640" width="480" preload="metadata" controls>
 % for my $s (@{$l->{sources} || []}) {
   <source src="<%= $s->{url} %>" type="<%= $s->{type} || '' %>">
 % }
