@@ -34,16 +34,10 @@ sub _fetch_paste {
   return $self->title("Paste $paste_id")->type("rich");
 }
 
-sub _parse_paste { $_[0]->_paste($_[1]->res->body) }
-
-sub _template {
-  my $self = shift;
-  return $self->SUPER::_template(@_) unless $self->_paste;
-  return __PACKAGE__, 'rich.html.ep';
+sub _parse_paste {
+  my ($self, $tx) = @_;
+  $self->{paste} = $tx->res->body;
+  $self->template->[1] = 'paste.html.ep';
 }
 
 1;
-
-__DATA__
-@@ rich.html.ep
-<pre><%= $l->_paste %></pre>
